diff --git a/X10D/src/ExceptionMessages.resx b/X10D/src/ExceptionMessages.resx
index 859f26f..c3f36f9 100644
--- a/X10D/src/ExceptionMessages.resx
+++ b/X10D/src/ExceptionMessages.resx
@@ -38,8 +38,8 @@
HashAlgorithm's Create method returned null referenece.
-
- Length must be a positive value.
+
+ Length must be greater than or equal to 0.
The stream does not support reading.
diff --git a/X10D/src/RandomExtensions/RandomExtensions.cs b/X10D/src/RandomExtensions/RandomExtensions.cs
index 088f685..6fabcd7 100644
--- a/X10D/src/RandomExtensions/RandomExtensions.cs
+++ b/X10D/src/RandomExtensions/RandomExtensions.cs
@@ -333,7 +333,7 @@ namespace X10D.RandomExtensions
if (length < 0)
{
- throw new ArgumentOutOfRangeException(nameof(length), ExceptionMessages.LengthMustBePositiveValue);
+ throw new ArgumentOutOfRangeException(nameof(length), ExceptionMessages.LengthGreaterThanOrEqualTo0);
}
if (length == 0)
diff --git a/X10D/src/ExceptionMessages.Designer.cs b/X10D/src/ExceptionMessages.Designer.cs
index d87a8e2..0e6da91 100644
--- a/X10D/src/ExceptionMessages.Designer.cs
+++ b/X10D/src/ExceptionMessages.Designer.cs
@@ -79,11 +79,11 @@ namespace X10D {
}
///
/// Looks up a localized string similar to Length must be a positive value..
///
- internal static string LengthMustBePositiveValue {
+ internal static string LengthGreaterThanOrEqualTo0 {
get {
- return ResourceManager.GetString("LengthMustBePositiveValue", resourceCulture);
+ return ResourceManager.GetString("LengthGreaterThanOrEqualTo0", resourceCulture);
}
}
@@ -79,11 +79,11 @@ namespace X10D {
}
///
- /// Looks up a localized string similar to Length must be a positive value..
+ /// Looks up a localized string similar to Length must be greater than or equal to 0..
///